
---
title: my_site
keywords: my_site
desc: my_site, generated with teedoc, a static site generator
id: home_page
---




<div>
    <h1><span>my_site</span></h1>
    <h3>好耶~ 网站出现啦！</h3>
</div>
<div id="big_btn_wrapper">
    <a class="btn" href="/doc1/">See Doc1</a>
</div>

